@@ -57,8 +57,6 @@ using namespace Soprano::Vocabulary;
 TagsProtocol::TagsProtocol(const QByteArray& pool_socket, const QByteArray& app_socket)
     : KIO::ForwardingSlaveBase("tags", pool_socket, app_socket)
 {
-    // Load all the tag uris on start so that they are always there in the cache
-    m_allTags = Tag::allTags();
 }
 
 TagsProtocol::~TagsProtocol()
@@ -89,7 +87,7 @@ namespace {
         uds.insert( KIO::UDSEntry::UDS_ACCESS, 0700 );
         uds.insert( KIO::UDSEntry::UDS_USER, KUser().loginName() );
         uds.insert( KIO::UDSEntry::UDS_NEPOMUK_URI, tag.uri().toString() );
-        uds.insert( KIO::UDSEntry::UDS_ICON_NAME, QLatin1String("nepomuk") );
+        uds.insert( KIO::UDSEntry::UDS_ICON_NAME, QLatin1String("feed-subscribe") );
 
         return uds;
     }
@@ -109,8 +107,15 @@ void TagsProtocol::listDir(const KUrl& url)
 
         case RootUrl: {
             kDebug() << "Root Url";
-            foreach( const Tag& tag, m_allTags ) {
+
+            QLatin1String query("select ?r where { ?r a nao:Tag . }");
+            Soprano::Model* model = ResourceManager::instance()->mainModel();
+            Soprano::QueryResultIterator it = model->executeQuery( query, Soprano::Query::QueryLanguageSparql );
+            while( it.next() ) {
+                Tag tag( it[0].uri() );
                 listEntry( createUDSEntryForTag(tag), false );
+
+                m_allTags << tag;
             }
 
             listEntry( KIO::UDSEntry(), true );
@@ -224,7 +229,7 @@ void TagsProtocol::stat(const KUrl& url)
             uds.insert( KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR );
             uds.insert( KIO::UDSEntry::UDS_MIME_TYPE, QString::fromLatin1( "inode/directory" ) );
 
-            uds.insert( KIO::UDSEntry::UDS_ICON_OVERLAY_NAMES, QLatin1String( "nepomuk" ) );
+            uds.insert( KIO::UDSEntry::UDS_ICON_OVERLAY_NAMES, QLatin1String( "feed-subscribe" ) );
             uds.insert( KIO::UDSEntry::UDS_DISPLAY_TYPE, i18n( "Tag" ) );
 
             uds.insert( KIO::UDSEntry::UDS_NAME, QLatin1String(".") );
