@@ -82,7 +82,9 @@ void IconItem::setSource(const QVariant &source)
         m_svgIcon = 0;
 
     } else if (source.canConvert<QString>()) {
-        m_svgIcon = new Plasma::Svg(this);
+        if (!m_svgIcon) {
+            m_svgIcon = new Plasma::Svg(this);
+        }
         //try as a svg toolbar icon
         m_svgIcon->setImagePath("toolbar-icons/" + source.toString().split("-").first());
 
@@ -128,7 +130,9 @@ void IconItem::setSource(const QVariant &source)
         m_svgIcon = 0;
     }
 
-    loadPixmap();
+    if (width() > 0 && height() > 0) {
+        loadPixmap();
+    }
 
     emit sourceChanged();
     emit validChanged();
@@ -203,7 +207,7 @@ bool IconItem::smooth() const
 
 bool IconItem::isValid() const
 {
-    return !m_iconPixmaps.isEmpty();
+    return !m_icon.isNull() || m_svgIcon || !m_pixmapIcon.isNull() || !m_imageIcon.isNull();
 }
 
 void IconItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
@@ -272,13 +276,16 @@ void IconItem::loadPixmap()
     }
 
 
-
     //final pixmap to paint
     QPixmap result;
-    if (m_svgIcon) {
+    if (size <= 0) {
+        m_animation->stop();
+        update();
+        return;
+    } else if (m_svgIcon) {
         m_svgIcon->resize(size, size);
         result = m_svgIcon->pixmap(m_source.toString());
-    } else if (!m_source.isNull()) {
+    } else if (!m_source.isNull() && size>0) {
         result = m_icon.pixmap(QSize(size, size));
     } else if (!m_pixmapIcon.isNull()) {
         result = m_pixmapIcon;
@@ -286,6 +293,8 @@ void IconItem::loadPixmap()
         result = QPixmap::fromImage(m_imageIcon);
     } else {
         m_iconPixmaps.clear();
+        m_animation->stop();
+        update();
         return;
     }
 
@@ -319,10 +328,12 @@ void IconItem::geometryChanged(const QRectF &newGeometry,
 {
     if (newGeometry.size() != oldGeometry.size()) {
         m_iconPixmaps.clear();
-        loadPixmap();
-    }
+        if (newGeometry.width() > 0 && newGeometry.height() > 0) {
+            loadPixmap();
+        }
 
-    QDeclarativeItem::geometryChanged(newGeometry, oldGeometry);
+        QDeclarativeItem::geometryChanged(newGeometry, oldGeometry);
+    }
 }
 
 #include "iconitem.moc"
